<?php
require __DIR__ . '/vendor/autoload.php';

function insert_data_google_sheet($sheetID = '', $sheetName = '', $data = [])
{
    $client = new \Google_Client();
    $client->setApplicationName('Google Sheets with Primo');
    $client->setScopes([\Google_Service_Sheets::SPREADSHEETS]);
    $client->setAccessType('offline');
    $client->setAuthConfig(__DIR__ . '/credentials.json');

    $service = new Google_Service_Sheets($client);
    $spreadsheetId = $sheetID;
    $range = $sheetName;

    try {
        // Check the existing values in the sheet
        $response = $service->spreadsheets_values->get($spreadsheetId, $range);
        $existingValues = $response->getValues();
    } catch (Exception $e) {
        die('Error retrieving existing values: ' . $e->getMessage());
    }


    // Extract existing appointment IDs to check for duplicates
    $existingIds = array_column($existingValues, 0);

    // Filter out duplicates
    $filteredData = array_filter($data, function ($row) use ($existingIds) {
        return !in_array($row[0], $existingIds);
    });

    if (empty($filteredData)) {
        echo "No new data to insert.";
        return;
    }

    // Define the range to append data starting from the next row
    $values = array_values($filteredData); // array_values to reindex filteredData array
    $body = new Google_Service_Sheets_ValueRange([
        'values' => $values
    ]);
    $params = [
        'valueInputOption' => 'RAW'
    ];

    $result = $service->spreadsheets_values->append(
        $spreadsheetId,
        $range,
        $body,
        $params
    );

    if ($result->updates->updatedRows > 0) {
        echo "Success";
    } else {
        echo "Fail";
    }
}


$sheetID = "1gEeUFv88O_vecU4lmgs2ujkiQQZjtB3Wb-JXZqQ7tsE";
$sheetName = "Mint Pest";



/**
 * retrieve previous date from  EDT timezone
 */
function get_previous_date_edt()
{

    $timezone = new DateTimeZone('America/New_York'); // Set the timezone to EDT
    $now = new DateTime('now', $timezone); // Create a DateTime object for the current date/time
    $now->sub(new DateInterval('P1D')); // Subtract one day
    $previous_date = $now->format('Y-m-d'); // Format the date according to your needs

    return $previous_date;
}

$prev_dt = get_previous_date_edt();

$appointment_ids = $customer_ids = $appointment_type_ids  = $sheet_data = [];
$appointment_id = $appointment_type = $appointment_date = $customer_phone = $customer_fname = "";

$base_url               = 'https://mintpest.fieldroutes.com/api';
$authenticationKey      = '78m4123bukkepv6fkbgcs1d9m4pro8l8qtbk2v4v06puk9d1j65951gmklaevtgj';
$authenticationToken    = 'crogal2h5ee24gbos6edu5o91592ons909el99rj19hipp5i2pbsr86hdev4l2ei';
$auth_url               = 'authenticationKey=' . $authenticationKey . '&authenticationToken=' . $authenticationToken;

//APIs Endpoints
$search_all_appointment     = '/appointment/search/';   // to retrieve all the appointment ids
$search_single_appointment  = '/appointment/';          // to retrieve single appointment details
$search_customer            = '/customer/';             // to retrieve customer details
$search_appointment_type    = '/serviceType/';          // to retrieve appointment type details

$dateAddedEnd = $dateAddedStart = $prev_dt;
// $dateAddedEnd = $dateAddedStart = '2024-06-17';

$get_appointments_url = $base_url . $search_all_appointment . '?dateAddedStart=' . $dateAddedStart . '&dateAddedEnd=' . $dateAddedEnd . '&' . $auth_url;

// https://mintpest.fieldroutes.com/api/appointment/search?dateAddedStart=2024-06-17&dateAddedEnd=2024-06-17&authenticationKey=78m4123bukkepv6fkbgcs1d9m4pro8l8qtbk2v4v06puk9d1j65951gmklaevtgj&authenticationToken=crogal2h5ee24gbos6edu5o91592ons909el99rj19hipp5i2pbsr86hdev4l2ei

$get_appointments_response = @file_get_contents($get_appointments_url);
if ($get_appointments_response === FALSE) {
    die('Error occurred while fetching appointments');
}
$get_appointments_data = json_decode($get_appointments_response, true);

if (!empty($get_appointments_data['success'])) {
    $appointment_ids = array_reverse($get_appointments_data['appointmentIDs']);
    if (!empty($appointment_ids)) {

        foreach ($appointment_ids as $key => $appointment_id) {
            $get_single_appointment_url = $base_url . $search_single_appointment . '/' . $appointment_id . '?' . $auth_url;
            // https://mintpest.fieldroutes.com/api/appointment/110025?&authenticationKey=78m4123bukkepv6fkbgcs1d9m4pro8l8qtbk2v4v06puk9d1j65951gmklaevtgj&authenticationToken=crogal2h5ee24gbos6edu5o91592ons909el99rj19hipp5i2pbsr86hdev4l2ei

            $get_single_appointment_response = @file_get_contents($get_single_appointment_url);
            if ($get_single_appointment_response === FALSE) {
                die('Error occurred while fetching single appointment');
            }

            $get_single_appointment_data = json_decode($get_single_appointment_response, true);

            if (!empty($get_single_appointment_data['success'])) {
                $appointment_date = $get_single_appointment_data['appointment']['date']; // anointment date
                $customer_id = $get_single_appointment_data['appointment']['customerID'];

                $get_customer_url = $base_url . $search_customer . '/' . $customer_id . '?' . $auth_url;
                // https://mintpest.fieldroutes.com/api/customer/20585?&authenticationKey=78m4123bukkepv6fkbgcs1d9m4pro8l8qtbk2v4v06puk9d1j65951gmklaevtgj&authenticationToken=crogal2h5ee24gbos6edu5o91592ons909el99rj19hipp5i2pbsr86hdev4l2ei

                $get_customer_response = @file_get_contents($get_customer_url);
                if ($get_customer_response === FALSE) {
                    die('Error occurred while fetching customer details');
                }
                $get_customer_data = json_decode($get_customer_response, true);

                $customer_fname  = $get_customer_data['customer']['fname']; // custom first name
                $customer_phone  = $get_customer_data['customer']['billingPhone']; // customer phone number

                $appointment_type_id = $get_single_appointment_data['appointment']['type'];
                $get_appointment_type_url = $base_url . $search_appointment_type . '/' . $appointment_type_id . '?' . $auth_url;
                // https://mintpest.fieldroutes.com/api/customer/20585?&authenticationKey=78m4123bukkepv6fkbgcs1d9m4pro8l8qtbk2v4v06puk9d1j65951gmklaevtgj&authenticationToken=crogal2h5ee24gbos6edu5o91592ons909el99rj19hipp5i2pbsr86hdev4l2ei

                $get_appointment_type_response = @file_get_contents($get_appointment_type_url);
                if ($get_appointment_type_response === FALSE) {
                    die('Error occurred while fetching appointment type details');
                }
                $get_appointment_type_data = json_decode($get_appointment_type_response, true);

                $appointment_type = $get_appointment_type_data['serviceType']['description']; // appointment type

                $sheet_data[] = [
                    $appointment_id,
                    $customer_fname,
                    $customer_phone,
                    $appointment_date,
                    $appointment_type,
                ];
            } else {
                die($get_single_appointment_data['errorMessage']);
            }
        }
        // Insert the data into the Google Sheet
        insert_data_google_sheet($sheetID, $sheetName, $sheet_data);
    } else {
        echo "No apponiment found";
    }
} else {
    die($get_appointments_data['errorMessage']);
}
